<?php # lang_cz.inc.php 1501.1 2009-08-15 10:29:04 VladaAjgl $

/**
 *  @version 1501.1
 *  @author Vladimír Ajgl <vlada@ajgl.cz>
 *  EN-Revision: Revision of lang_en.inc.php
 *  Translated on 2007/11/30
 *  @author Vladimír Ajgl <vlada@ajgl.cz>
 *  @revisionDate 2009/05/06
 *  @author Vladimír Ajgl <vlada@ajgl.cz>
 *  @revisionDate 2009/08/15
 */

@define('PLUGIN_EVENT_NL2BR_NAME',              'Markup: NL2BR');
@define('PLUGIN_EVENT_NL2BR_DESC',              'Mění znaky konce řádku na tagy <br />');
@define('PLUGIN_EVENT_NL2BR_ISOLATE_TAGS',      'Seznam html tagů, uvnitř kterých nemají být konce řádků nahrazovány.');
@define('PLUGIN_EVENT_NL2BR_ISOLATE_TAGS_DESC', 'Návrhy: "code,pre,geshi,textarea". Názvy tagů oddělujte čárkou. Tip: Zadávané tagy jsou vyhodnocovány jako regulární výraz.');
@define('PLUGIN_EVENT_NL2BR_PTAGS',              'Použít tagy &lt;p&gt;');
@define('PLUGIN_EVENT_NL2BR_PTAGS_DESC',              'Vkládat tagy &lt;p&gt; místo tagů &lt;br /&gt;');